<?php
/**
 * Theme Customiser
 *
 * @package productive-ecommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
    die();
}


if ( ! class_exists( 'Productive_Theme_Customiser_Homepage_Blog' ) ) {
    
    /**
     * Productive_Theme_Customiser_Homepage_Blog
     * Theme Customiser Class
     */
    class Productive_Theme_Customiser_Homepage_Blog extends Productive_Theme_Customiser_Common {
        
        /**
         * Register the customizer
         *
         * @param WP_Customize_Manager $wp_customise param.
         */
        public static function register( $wp_customise ) {
            
            // See common for Panels
            // 
            // Section
            $wp_customise->add_section(
                'productive_ecommerce_homepage_blog_options',
                array(
                    'title' => __( 'Blog Categories', 'productive-ecommerce' ),
                    'description' => __( 'Blog Categories (Archive) Options', 'productive-ecommerce' ),
                    'panel' => 'productive_ecommerce_theme_options',
                    'priority' => 30,
                    'capability' => 'edit_theme_options',
                )
                );

            // add a setting for productive_ecommerce_posts_excerpt_word_count, below.
            $wp_customise->add_setting(
                'productive_ecommerce_posts_excerpt_word_count',
                array(
                    'type' => 'theme_mod',
                    'default' => 20,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_absint'),
                )
                );
            $wp_customise->add_control(
                'productive_ecommerce_posts_excerpt_word_count',
                array(
                    'type' => 'number',
                    'priority' => 10, 
                    'section' => 'productive_ecommerce_homepage_blog_options',
                    'label' => __( 'Excerpt Word Count', 'productive-ecommerce' ),
                    'description' => __( 'Number of words to display in post excerpts.', 'productive-ecommerce' ),
                    'input_attrs' => array(
                        'min' => 10,
                        'max' => 30,
                        'step' => 1,
                    ),
                )
                );
            
            // add a setting for productive_ecommerce_items_per_row_to_display, below.
            $wp_customise->add_setting(
                'productive_ecommerce_items_per_row_to_display',
                array(
                    'type' => 'theme_mod',
                    'default' => '3',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_absint'),
                )
                );
            $wp_customise->add_control(
                'productive_ecommerce_items_per_row_to_display',
                array(
                    'type' => 'number',
                    'priority' => 10, 
                    'section' => 'productive_ecommerce_homepage_blog_options',
                    'label' => __( 'Number of Blog Posts Per Row', 'productive-ecommerce' ),
                    'description' => __( 'Use 3 or more for best result', 'productive-ecommerce' ),
                    'input_attrs' => array(
                        'min' => 2,
                        'max' => 5,
                        'step' => 1,
                    ),
                )
                );
            
            // add a setting for productive_ecommerce_post_archive_title_color control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_post_archive_title_color',
                array(
                    'type' => 'theme_mod',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'default'              => '',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_color'),
                )
                );
            $wp_customise->add_control(
                new WP_Customize_Color_Control(
                    $wp_customise,
                    'productive_ecommerce_post_archive_title_color',
                    array(
                        'priority' => 20,
                        'label' => __( 'Colour for Blog Category Title', 'productive-ecommerce' ),
                        'section' => 'productive_ecommerce_homepage_blog_options',
                    )
                    )
                );
            
            // add a setting for productive_ecommerce_posts_placeholder_image control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_posts_placeholder_image',
                array(
                    'type' => 'theme_mod',
                    'default' => true,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_image'),
                )
                );
            
            // add control.
            $wp_customise->add_control(
                new WP_Customize_Media_Control(
                    $wp_customise,
                    'productive_ecommerce_posts_placeholder_image',
                    array(
                        'priority' => 40, // 30 is used in extra. So this will be 40
                        'section' => 'productive_ecommerce_homepage_blog_options',
                        'label' => __( 'Blog Post Placeholder Thumbnail', 'productive-ecommerce' ),
                        'description' => __( 'An image that shows as thumbnail if a blog post does not have one', 'productive-ecommerce' ),
                        // 'active_callback' => 'is_front_page'
                    )
                    )
                );
            
            
        }
        
    } // End of class.
    
    // add hook for the class.
    add_action( 'customize_register', array( 'Productive_Theme_Customiser_Homepage_Blog', 'register' ) );
    
} // End of if class exists



/**
 * Method productive_ecommerce_posts_excerpt_word_count.
 *
 * @param string $class ''.
 */
function productive_ecommerce_posts_excerpt_word_count( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_posts_excerpt_word_count', 20 );
}
add_action( 'display_productive_ecommerce_posts_excerpt_word_count', 'productive_ecommerce_posts_excerpt_word_count' );


/**
 * Method productive_ecommerce_items_per_row_to_display.
 *
 * @param string $class ''.
 */
function productive_ecommerce_items_per_row_to_display( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_items_per_row_to_display', 3 );
}
add_action( 'display_productive_ecommerce_items_per_row_to_display', 'productive_ecommerce_items_per_row_to_display' );

/**
 * Method productive_ecommerce_posts_placeholder_image.
 *
 * @param string $class ''.
 */
function productive_ecommerce_posts_placeholder_image( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_posts_placeholder_image' );
}
add_action( 'display_productive_ecommerce_posts_placeholder_image', 'productive_ecommerce_posts_placeholder_image' );

/**
 * Method productive_ecommerce_post_archive_title_color.
 *
 * @param string $class ''.
 */
function productive_ecommerce_post_archive_title_color( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_post_archive_title_color', '' );
}
add_action( 'display_productive_ecommerce_post_archive_title_color', 'productive_ecommerce_post_archive_title_color' );




// BLOG CATEGORIES
/**
 * Method productive_ecommerce_post_archive_banner_image.
 *
 * @param string $class ''.
 */
function productive_ecommerce_post_archive_banner_image( $class = '' ) {
    // image
    return get_theme_mod( 'productive_ecommerce_post_archive_banner_image' );
}
add_action( 'display_productive_ecommerce_post_archive_banner_image', 'productive_ecommerce_post_archive_banner_image' );


