<?php
/**
 * Theme Customiser
 *
 * @package productive-ecommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
    die();
}


if ( ! class_exists( 'Productive_Theme_Customiser_Footer' ) ) {
    
    /**
     * Productive_Theme_Customiser_Footer
     * Theme Customiser Class
     */
    class Productive_Theme_Customiser_Footer extends Productive_Theme_Customiser_Common {
        
        /**
         * Register the customizer
         *
         * @param WP_Customize_Manager $wp_customise param.
         */
        public static function register( $wp_customise ) {
            
            $footer_section_desc = esc_html__( 'Footer Options ', 'productive-ecommerce' );
            $pro_only_message = esc_html__( ' (Copyright management is Pro only feature)', 'productive-ecommerce' );
            if ( function_exists( 'productiveminds_theme_extra_is_active' ) ) {
                $pro_only_message = '';
            }
            // See common for Panels
            // Section
            // first, add a productive_ecommerce_footer_options for the theme.
            $footer_section_desc = $footer_section_desc . $pro_only_message;
            $wp_customise->add_section(
                'productive_ecommerce_footer_options',
                array(
                    'title' => __( 'Footer Options', 'productive-ecommerce' ),
                    'description' => $footer_section_desc,
                    'panel' => 'productive_ecommerce_theme_options',
                    'priority' => 80,
                    'capability' => 'edit_theme_options',
                )
                );
            
            // add a setting for productive_ecommerce_enable_footer_business_hours control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_enable_footer_business_hours',
                array(
                    'type' => 'theme_mod',
                    'default' => true,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_checkbox'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_enable_footer_business_hours',
                array(
                    'type' => 'checkbox',
                    'priority' => 2,
                    'section' => 'productive_ecommerce_footer_options',
                    'label' => __( 'Show Business Hours in Footer?', 'productive-ecommerce' ),
                    'description' => __( 'Display business hours (opening hours) in website footer', 'productive-ecommerce' ),
                    // 'active_callback' => 'is_front_page',
                )
                );
            
            // add a setting for productive_ecommerce_enable_footer_business_address control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_enable_footer_business_address',
                array(
                    'type' => 'theme_mod',
                    'default' => true,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_checkbox'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_enable_footer_business_address',
                array(
                    'type' => 'checkbox',
                    'priority' => 4,
                    'section' => 'productive_ecommerce_footer_options',
                    'label' => __( 'Show Business Location in Footer?', 'productive-ecommerce' ),
                    'description' => __( 'Display business location (physical address) in website footer', 'productive-ecommerce' ),
                    // 'active_callback' => 'is_front_page',
                )
                );
            
            // add a setting for productive_ecommerce_enable_footer_sitedesc control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_enable_footer_sitedesc',
                array(
                    'type' => 'theme_mod',
                    'default' => true,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_checkbox'),
                )
                );
            // add control.
            $wp_customise->add_control(
                'productive_ecommerce_enable_footer_sitedesc',
                array(
                    'type' => 'checkbox',
                    'priority' => 22,
                    'section' => 'productive_ecommerce_footer_options',
                    'label' => __( 'Show Website Description in Footer?', 'productive-ecommerce' ),
                    'description' => __( 'Display the Description of your website in the footer?', 'productive-ecommerce' ),
                    // 'active_callback' => 'is_front_page',
                )
                );
            
            // add a setting for productive_ecommerce_footer_copyright_textarea control, below.
            $url = wp_specialchars_decode( stripslashes( esc_url( PRODUCTIVE_ECOMMERCE_THEME_DEVELOPER_WEBSITE ) ) );
            $wp_customise->add_setting(
                'productive_ecommerce_footer_copyright_textarea',
                array(
                    'type' => 'theme_mod',
                    'default' => __( 'A WordPress theme by ', 'productive-ecommerce' ) . '<a target="_blank" href="' . $url . '">' . esc_attr( PRODUCTIVE_ECOMMERCE_THEME_DEVELOPER_NAME ) . '</a>',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_html'),
                )
                );
                // add control..
            if ( !function_exists( 'productiveminds_theme_extra_is_active' ) ) {
                
                // add control..
                $wp_customise->add_control(
                    'productive_ecommerce_footer_copyright_textarea',
                    array(
                        'type' => 'hidden',
                        'priority' => 40,
                        'section' => 'productive_ecommerce_footer_options',
                        'label' => __( 'Footer copyright', 'productive-ecommerce' ),
                        'description' => '<a href="' . esc_url( PRODUCTIVE_ECOMMERCE_THEME_FEATURES_OR_BUY_URL ) . '">' . esc_html__( 'You need the Pro version', 'productive-ecommerce' ) . '</a> ' . esc_html__( ' to remove or change the Footer copyright', 'productive-ecommerce' ),
                    )
                    );
            } else {
                
                // add control..
                $wp_customise->add_control(
                    'productive_ecommerce_footer_copyright_textarea',
                    array(
                        'type' => 'textarea',
                        'priority' => 40,
                        'section' => 'productive_ecommerce_footer_options',
                        'label' => __( 'Footer copyright content', 'productive-ecommerce' ),
                        'description' => __( 'Leave blank for no copyright info', 'productive-ecommerce' ),
                    )
                    );
            }
                
            
            // start callouts
            if ( !function_exists( 'productiveminds_theme_extra_is_active' ) ) {
                // add a setting for productive_ecommerce_pro_callout_1, below.
                $productive_ecommerce_pro_callout_features_label = esc_attr( 'Get more features with PRO', 'productive-ecommerce' );
                $productive_ecommerce_pro_callout_features_url = '<a target="_blank" class="get-pro-button" href="' .
                    esc_url( PRODUCTIVE_ECOMMERCE_THEME_FEATURES_OR_BUY_URL ) . '">' .
                    esc_html__( 'Compare Pro and Free Features', 'productive-ecommerce' ) . '</a> ';
                $productive_ecommerce_pro_callout_demo_url = '<a target="_blank" class="get-pro-button" href="' .
                    esc_url( PRODUCTIVE_ECOMMERCE_THEME_DEMO_URL ) . '">' . esc_html__( 'See a Live Demo', 'productive-ecommerce' ) . '</a>';
                $productive_ecommerce_pro_callout_docs_url = '<a target="_blank" class="get-pro-button" href="' .
                    esc_url( PRODUCTIVE_ECOMMERCE_THEME_DOCUMENTATION_URL ) . '">' . esc_html__( 'See the Documentation', 'productive-ecommerce' ) . '</a>';
            
                $wp_customise->add_setting(
                    'productive_ecommerce_pro_callout_header',
                    array(
                        'type' => 'theme_mod',
                        'default' => '',
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_html'),
                    )
                    );
                // add control..
                $wp_customise->add_control(
                    'productive_ecommerce_pro_callout_header',
                    array(
                        'type' => 'hidden',
                        'priority' => 200,
                        'section' => 'productive_ecommerce_theme_header',
                        'label' => $productive_ecommerce_pro_callout_features_label,
                        'description' => $productive_ecommerce_pro_callout_features_url,
                    )
                    );
                
                $wp_customise->add_setting(
                    'productive_ecommerce_pro_callout_header_demo',
                    array(
                        'type' => 'theme_mod',
                        'default' => '',
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_html'),
                    )
                    );
                // add control..
                $wp_customise->add_control(
                    'productive_ecommerce_pro_callout_header_demo',
                    array(
                        'type' => 'hidden',
                        'priority' => 210,
                        'section' => 'productive_ecommerce_theme_header',
                        'label' => '',
                        'description' => $productive_ecommerce_pro_callout_demo_url,
                    )
                    );
                
                $wp_customise->add_setting(
                    'productive_ecommerce_pro_callout_header_docs',
                    array(
                        'type' => 'theme_mod',
                        'default' => '',
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_html'),
                    )
                    );
                // add control..
                $wp_customise->add_control(
                    'productive_ecommerce_pro_callout_header_docs',
                    array(
                        'type' => 'hidden',
                        'priority' => 220,
                        'section' => 'productive_ecommerce_theme_header',
                        'label' => '',
                        'description' => $productive_ecommerce_pro_callout_docs_url,
                    )
                    );
                
                $wp_customise->add_setting(
                    'productive_ecommerce_pro_callout_homepage_options',
                    array(
                        'type' => 'theme_mod',
                        'default' => '',
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_html'),
                    )
                    );
                // add control..
                $wp_customise->add_control(
                    'productive_ecommerce_pro_callout_homepage_options',
                    array(
                        'type' => 'hidden',
                        'priority' => 200,
                        'section' => 'productive_ecommerce_homepage_options_banner_background',
                        'label' => $productive_ecommerce_pro_callout_features_label,
                        'description' => $productive_ecommerce_pro_callout_demo_url,
                    )
                    );
                
                $wp_customise->add_setting(
                    'productive_ecommerce_pro_callout_homepage_blog_options',
                    array(
                        'type' => 'theme_mod',
                        'default' => '',
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_html'),
                    )
                    );
                // add control..
                $wp_customise->add_control(
                    'productive_ecommerce_pro_callout_homepage_blog_options',
                    array(
                        'type' => 'hidden',
                        'priority' => 200,
                        'section' => 'productive_ecommerce_homepage_blog_options',
                        'label' => $productive_ecommerce_pro_callout_features_label,
                        'description' => $productive_ecommerce_pro_callout_features_url,
                    )
                    );
                
                $wp_customise->add_setting(
                    'productive_ecommerce_pro_callout_commerce_options',
                    array(
                        'type' => 'theme_mod',
                        'default' => '',
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_html'),
                    )
                    );
                // add control..
                $wp_customise->add_control(
                    'productive_ecommerce_pro_callout_commerce_options',
                    array(
                        'type' => 'hidden',
                        'priority' => 200,
                        'section' => 'productive_ecommerce_theme_commerce',
                        'label' => $productive_ecommerce_pro_callout_features_label,
                        'description' => $productive_ecommerce_pro_callout_demo_url,
                    )
                    );
                
                $wp_customise->add_setting(
                    'productive_ecommerce_pro_callout_layout_options',
                    array(
                        'type' => 'theme_mod',
                        'default' => '',
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_html'),
                    )
                    );
                // add control..
                $wp_customise->add_control(
                    'productive_ecommerce_pro_callout_layout_options',
                    array(
                        'type' => 'hidden',
                        'priority' => 200,
                        'section' => 'productive_ecommerce_layout_options',
                        'label' => $productive_ecommerce_pro_callout_features_label,
                        'description' => $productive_ecommerce_pro_callout_demo_url,
                    )
                    );
                
                $wp_customise->add_setting(
                    'productive_ecommerce_pro_callout_archive_options',
                    array(
                        'type' => 'theme_mod',
                        'default' => '',
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_html'),
                    )
                    );
                // add control..
                $wp_customise->add_control(
                    'productive_ecommerce_pro_callout_archive_options',
                    array(
                        'type' => 'hidden',
                        'priority' => 200,
                        'section' => 'productive_ecommerce_archive_options',
                        'label' => $productive_ecommerce_pro_callout_features_label,
                        'description' => $productive_ecommerce_pro_callout_features_url,
                    )
                    );
                
                $wp_customise->add_setting(
                    'productive_ecommerce_pro_callout_social_options_demo',
                    array(
                        'type' => 'theme_mod',
                        'default' => '',
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_html'),
                    )
                    );
                // add control..
                $wp_customise->add_control(
                    'productive_ecommerce_pro_callout_social_options_demo',
                    array(
                        'type' => 'hidden',
                        'priority' => 200,
                        'section' => 'productive_ecommerce_social_options',
                        'label' => '',
                        'description' => $productive_ecommerce_pro_callout_demo_url,
                    )
                    );
                
                $wp_customise->add_setting(
                    'productive_ecommerce_pro_callout_social_options_docs',
                    array(
                        'type' => 'theme_mod',
                        'default' => '',
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_html'),
                    )
                    );
                // add control..
                $wp_customise->add_control(
                    'productive_ecommerce_pro_callout_social_options_docs',
                    array(
                        'type' => 'hidden',
                        'priority' => 210,
                        'section' => 'productive_ecommerce_social_options',
                        'label' => '',
                        'description' => $productive_ecommerce_pro_callout_docs_url,
                    )
                    );
                
                $wp_customise->add_setting(
                    'productive_ecommerce_pro_callout_footer_options',
                    array(
                        'type' => 'theme_mod',
                        'default' => '',
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_html'),
                    )
                    );
                // add control..
                $wp_customise->add_control(
                    'productive_ecommerce_pro_callout_footer_options',
                    array(
                        'type' => 'hidden',
                        'priority' => 200,
                        'section' => 'productive_ecommerce_footer_options',
                        'label' => $productive_ecommerce_pro_callout_features_label,
                        'description' => $productive_ecommerce_pro_callout_features_url,
                    )
                    );
            }
            // end callouts
                
                
        }
        
        
    } // End of class.
    
    // add hook for the class.
    add_action( 'customize_register', array( 'Productive_Theme_Customiser_Footer', 'register' ) );
    
} // End of if class exists



/**
 * Method productive_ecommerce_enable_footer_business_hours.
 *
 * @param string $class ''.
 */
function productive_ecommerce_enable_footer_business_hours( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_enable_footer_business_hours', true );
}

/**
 * Method productive_ecommerce_enable_footer_business_address.
 *
 * @param string $class ''.
 */
function productive_ecommerce_enable_footer_business_address( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_enable_footer_business_address', true );
}

/**
 * Method productive_ecommerce_enable_footer_copyright.
 *
 * @param string $class ''.
 */
function productive_ecommerce_enable_footer_copyright( $class = '' ) {
    $theme_mod_enabled = get_theme_mod( 'productive_ecommerce_enable_footer_copyright', true );
    if ( (function_exists( 'productiveminds_theme_extra_is_active' ) && $theme_mod_enabled) || !function_exists( 'productiveminds_theme_extra_is_active' ) ) {
        echo '<div class="site-container-copyright">
            <div class="copyright">' .
                wp_specialchars_decode( stripslashes(productive_ecommerce_footer_copyright_textarea()) ).
            '</div>
        </div>';
    }
}
add_action( 'display_productive_ecommerce_enable_footer_copyright', 'productive_ecommerce_enable_footer_copyright' );

/**
 * Method productive_ecommerce_footer_copyright_textarea.
 *
 * @param string $class ''.
 */
function productive_ecommerce_footer_copyright_textarea( $class = '' ) {
    $footer_copyright_copy = esc_html( 'A WordPress theme by ', 'productive-ecommerce' ).'<a target="_blank" href="' . esc_url( PRODUCTIVE_ECOMMERCE_THEME_DEVELOPER_WEBSITE ) . '">productiveminds.com</a>';
    if ( function_exists( 'productiveminds_theme_extra_is_active' ) ) {
        $footer_copyright = get_theme_mod( 'productive_ecommerce_footer_copyright_textarea', $footer_copyright_copy );
        return $footer_copyright;
    } else {
        return $footer_copyright_copy;
    }
}
add_action( 'display_productive_ecommerce_footer_copyright_textarea', 'productive_ecommerce_footer_copyright_textarea' );




// FOOTER
/**
 * Method productive_ecommerce_footer_style.
 *
 * @param string $class ''.
 */
function productive_ecommerce_footer_style( $class = '' ) {
    $default_value = PRODUCTIVE_ECOMMERCE_CURRENT_THEME_TEXT_DOMAIN;
    $theme_mod_value = get_theme_mod( 'productive_ecommerce_footer_style', PRODUCTIVE_ECOMMERCE_CURRENT_THEME_TEXT_DOMAIN );
    if ( !$theme_mod_value ) {
        // 
    } else {
        $default_value = $theme_mod_value;
    }
    return $default_value;
}
add_action( 'display_productive_ecommerce_footer_style', 'productive_ecommerce_footer_style' );

function productive_ecommerce_enable_footer_sitelogo_enabled() {
    return get_theme_mod( 'productive_ecommerce_enable_footer_sitelogo', true );
}
/**
 * Method productive_ecommerce_enable_footer_sitelogo.
 *
 * @param string $class ''.
 */
function productive_ecommerce_enable_footer_sitelogo( $class = '' ) {
    if (productive_ecommerce_enable_footer_sitelogo_enabled() ) {
        echo '<div class="' . $class . '">' .
        get_custom_logo() .
            '</div>';
    }
}
add_action( 'display_productive_ecommerce_enable_footer_sitelogo', 'productive_ecommerce_enable_footer_sitelogo' );

function productive_ecommerce_enable_footer_sitename_enabled() {
    return get_theme_mod( 'productive_ecommerce_enable_footer_sitename', true );
}
/**
 * Method productive_ecommerce_enable_footer_sitename.
 *
 * @param string $class ''.
 */
function productive_ecommerce_enable_footer_sitename( $class = '' ) {
    if (productive_ecommerce_enable_footer_sitename_enabled() ) {
        echo '<div class="' . $class . '">' .
            '<div class="h5">' . get_bloginfo( 'name' ) . '</div>' .
        '</div>';
    }
}
add_action( 'display_productive_ecommerce_enable_footer_sitename', 'productive_ecommerce_enable_footer_sitename' );

function productive_ecommerce_enable_footer_sitedesc_enabled() {
    return get_theme_mod( 'productive_ecommerce_enable_footer_sitedesc', true );
}
/**
 * Method productive_ecommerce_enable_footer_sitedesc.
 *
 * @param string $class ''.
 */
function productive_ecommerce_enable_footer_sitedesc( $class = '' ) {
    if (productive_ecommerce_enable_footer_sitedesc_enabled() ) {
        echo '<div class="' . $class . '">' .
            '<div class="">' . get_bloginfo( 'description' ) . '</div>' .
        '</div>';
    }
}
add_action( 'display_productive_ecommerce_enable_footer_sitedesc', 'productive_ecommerce_enable_footer_sitedesc' );


/**
 * Method productive_ecommerce_enable_footer_site_logo_and_name.
 * 
 * @param string $class ''.
 */
function productive_ecommerce_enable_footer_site_logo_and_name( $class = '' ) {
    $theme_mod_enabled_logo = get_theme_mod( 'productive_ecommerce_enable_footer_sitelogo', true );
    if ( $theme_mod_enabled_logo ) {
        echo '<div class="footer-about-site-name ' . $class . '_logo">' .
        get_custom_logo() .
            '</div>';
    }
    
    $theme_mod_enabled = get_theme_mod( 'productive_ecommerce_enable_footer_sitename', true );
    if ( $theme_mod_enabled ) {
        echo '<div class="footer-about-site-name ' . $class . '">' .
            '<div class="footer-about-site-name-text">' . get_bloginfo( 'name' ) . '</div>' .
            '<div class="footer-about-site-desc-text">' . get_bloginfo( 'description' ) . '</div>' .
        '</div>';
    }
}
add_action( 'display_productive_ecommerce_enable_footer_site_logo_and_name', 'productive_ecommerce_enable_footer_site_logo_and_name' );
