<?php
/**
 * Theme Customiser
 *
 * @package productive-ecommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
    die();
}


if ( ! class_exists( 'Productive_Theme_Customiser_Header' ) ) {
    
    /**
     * Productive_Theme_Customiser_Header
     * Theme Customiser Class
     */
    class Productive_Theme_Customiser_Header extends Productive_Theme_Customiser_Common {
        
        /**
         * Register the customizer
         *
         * @param WP_Customize_Manager $wp_customise param.
         */
        public static function register( $wp_customise ) {
            
            // See common for Panels
            // 
            // Section
            $wp_customise->add_section(
                'productive_ecommerce_theme_header',
                array(
                    'title' => __( 'Header Options', 'productive-ecommerce' ),
                    'description' => __( 'Header Options', 'productive-ecommerce' ),
                    'panel' => 'productive_ecommerce_theme_options',
                    'priority' => 10,
                    'capability' => 'edit_theme_options',
                )
                );
            
            // add a setting for productive_ecommerce_the_logo_size control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_the_logo_size',
                array(
                    'type' => 'theme_mod',
                    'default' => PRODUCTIVE_ECOMMERCE_THE_LOGO_WIDTH_DEFAULT,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_absint'),
                )
            );
            $wp_customise->add_control(
                'productive_ecommerce_the_logo_size',
                array(
                    'type' => 'number',
                    'priority' => 2,
                    'section' => 'productive_ecommerce_theme_header',
                    'label' => __( 'Logo Width (px)', 'productive-ecommerce' ),
                    'description' => __( 'Increases or decreases logo width in px - height adjusts automatically.', 'productive-ecommerce' ),
                    'input_attrs' => array(
                        'min' => PRODUCTIVE_ECOMMERCE_THE_LOGO_WIDTH_MIN,
                        'max' => PRODUCTIVE_ECOMMERCE_THE_LOGO_WIDTH_MAX,
                        'step' => 20,
                    ),
                )
            );
            
            // add a setting for productive_ecommerce_enable_header_search control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_enable_header_search',
                array(
                    'type' => 'theme_mod',
                    'default' => true,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_checkbox'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_enable_header_search',
                array(
                    'type' => 'checkbox',
                    'priority' => 10,
                    'section' => 'productive_ecommerce_theme_header',
                    'label' => __( 'Show Header Search?', 'productive-ecommerce' ),
                    'description' => __( 'Display search box in the header', 'productive-ecommerce' ),
                    // 'active_callback' => 'is_front_page',
                )
                );
            
        }
        
        
    } // End of class.
    
    // add hook for the class.
    add_action( 'customize_register', array( 'Productive_Theme_Customiser_Header', 'register' ) );
    
} // End of if class exists


/**
 * 
 * Method productive_ecommerce_the_logo_size.
 *
 * @param string $class ''.
 */
function productive_ecommerce_the_logo_size( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_the_logo_size', PRODUCTIVE_ECOMMERCE_THE_LOGO_WIDTH_DEFAULT );
}

/**
 * Method productive_ecommerce_enable_header_search.
 *
 * @param string $class ''.
 */
function productive_ecommerce_enable_header_search( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_enable_header_search', true );
}
add_action( 'display_productive_ecommerce_enable_header_search', 'productive_ecommerce_enable_header_search' );




// HEADER 
/**
 * Method productive_ecommerce_enable_header_account.
 *
 * @param string $class ''.
 */
function productive_ecommerce_enable_header_account( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_enable_header_account', true );
}
add_action( 'display_productive_ecommerce_enable_header_account', 'productive_ecommerce_enable_header_account' );

/**
 * Method productive_ecommerce_header_style.
 *
 * @param string $class ''.
 */
function productive_ecommerce_header_style( $class = '' ) {
    $default_value = PRODUCTIVE_ECOMMERCE_CURRENT_THEME_TEXT_DOMAIN;
    $theme_mod_value = get_theme_mod( 'productive_ecommerce_header_style', PRODUCTIVE_ECOMMERCE_CURRENT_THEME_TEXT_DOMAIN );
    if ( $theme_mod_value ) {
        $default_value = $theme_mod_value;
    }    
    return $default_value;
}
add_action( 'display_productive_ecommerce_header_style', 'productive_ecommerce_header_style' );

/**
 * Method productive_ecommerce_homepage_blog_heading_style.
 *
 * @param string $class ''.
 */
function productive_ecommerce_homepage_blog_heading_style( $class = '' ) {
    if ( !function_exists( 'productiveminds_theme_extra_is_active' ) ) {
        return false;
    }
    $theme_mod_enabled = get_theme_mod( 'productive_ecommerce_homepage_blog_heading_style', true );
    return $theme_mod_enabled;
}
add_action( 'display_productive_ecommerce_homepage_blog_heading_style', 'productive_ecommerce_homepage_blog_heading_style' );
