<?php
/**
 * Theme Customiser
 *
 * @package productive-ecommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
    die();
}


if ( ! class_exists( 'Productive_Theme_Customiser_Homepage_Banner_Background' ) ) {
    
    /**
     * Productive_Theme_Customiser_Homepage_Banner_Background
     * Theme Customiser Class
     */
    class Productive_Theme_Customiser_Homepage_Banner_Background extends Productive_Theme_Customiser_Common {
        
        /**
         * Register the customizer
         *
         * @param WP_Customize_Manager $wp_customise param.
         */
        public static function register( $wp_customise ) {
            
            // See common for Panels
            // 
            // Section
            $panel = 'productive_ecommerce_theme_homepage_options';
            if ( productive_ecommerce_is_productive_style_active() || productive_ecommerce_is_productive_style_extra_active() ) {
                $panel = 'productive_style_theme_options_homepage';
            }
            $wp_customise->add_section(
                'productive_ecommerce_homepage_options_banner_background',
                array(
                    'title' => __( 'Homepage Banner', 'productive-ecommerce' ),
                    'description' => __( 'Homepage Banner Background control and Media', 'productive-ecommerce' ),
                    'panel' => $panel,
                    'priority' => 10,
                    'capability' => 'edit_theme_options',
                )
                );
            
            // add a setting for productive_ecommerce_is_homepage_banner_enable control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_is_homepage_banner_enable',
                array(
                    'type' => 'theme_mod',
                    'default' => true,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_checkbox'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_is_homepage_banner_enable',
                array(
                    'type' => 'checkbox',
                    'priority' => 10,
                    'section' => 'productive_ecommerce_homepage_options_banner_background',
                    'label' => __( 'Enable Banner in the Homepage?', 'productive-ecommerce' ),
                    'description' => __( 'Untick the box to hide the homepage banner', 'productive-ecommerce' ),
                    // 'active_callback' => 'is_front_page',
                )
                );
            
            // add a setting for productive_ecommerce_homepage_usp_image control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_homepage_usp_image',
                array(
                    'type' => 'theme_mod',
                    'default' => false,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_image'),
                )
                );
            // add control..
            $wp_customise->add_control(
                new WP_Customize_Media_Control(
                    $wp_customise,
                    'productive_ecommerce_homepage_usp_image',
                    array(
                        'priority' => 20,
                        'section' => 'productive_ecommerce_homepage_options_banner_background',
                        'label' => __( 'Background Image', 'productive-ecommerce' ),
                        'description' => __( 'The main background image in the homepage', 'productive-ecommerce' ),
                    )
                    )
                );
            
            // add a setting for productive_ecommerce_is_homepage_usp_scroll control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_is_homepage_usp_scroll',
                array(
                    'type' => 'theme_mod',
                    'default' => true,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_checkbox'),
                )
                );
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_is_homepage_usp_scroll',
                array(
                    'type' => 'checkbox',
                    'priority' => 30,
                    'section' => 'productive_ecommerce_homepage_options_banner_background',
                    'label' => __( 'Scroll Banner Background?', 'productive-ecommerce' ),
                    'description' => __( 'Image scrolls (if disabled, banner uses parallax effect)', 'productive-ecommerce' ),
                    // 'active_callback' => 'is_front_page',
                )
                );
            
            // add a setting for productive_ecommerce_is_homepage_banner_height control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_is_homepage_banner_height',
                array(
                    'type' => 'theme_mod',
                    'default' => PRODUCTIVE_ECOMMERCE_THE_BANNER_HEIGHT_DEFAULT,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_absint'),
                )
            );
            $wp_customise->add_control(
                'productive_ecommerce_is_homepage_banner_height',
                array(
                    'type' => 'number',
                    'priority' => 40,
                    'section' => 'productive_ecommerce_homepage_options_banner_background',
                    'label' => __( 'Banner Height (px)', 'productive-ecommerce' ),
                    'description' => '',
                    'input_attrs' => array(
                        'min' => PRODUCTIVE_ECOMMERCE_THE_BANNER_HEIGHT_MIN,
                        'max' => PRODUCTIVE_ECOMMERCE_THE_BANNER_HEIGHT_MAX,
                        'step' => 50,
                    ),
                )
            );
            
        }
    } // End of class.
    
    // add hook for the class.
    add_action( 'customize_register', array( 'Productive_Theme_Customiser_Homepage_Banner_Background', 'register' ) );
    
} // End of if class exists


/**
 * Method productive_ecommerce_is_homepage_banner_enable.
 *
 * @param string $class ''.
 */
function productive_ecommerce_is_homepage_banner_enable( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_is_homepage_banner_enable', true );
}

/**
 * Method productive_ecommerce_homepage_usp_image.
 *
 * @param string $class ''.
 */
function productive_ecommerce_homepage_usp_image( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_homepage_usp_image', false );
}

/**
 * Method productive_ecommerce_is_homepage_usp_scroll.
 *
 * @param string $class ''.
 */
function productive_ecommerce_is_homepage_usp_scroll( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_is_homepage_usp_scroll', true );
}

/**
 * Method productive_ecommerce_is_homepage_banner_height.
 *
 * @param string $class ''.
 */
function productive_ecommerce_is_homepage_banner_height( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_is_homepage_banner_height', PRODUCTIVE_ECOMMERCE_THE_BANNER_HEIGHT_DEFAULT );
}
