<?php
/**
 * Theme Customiser
 *
 * @package productive-ecommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
    die();
}


if ( ! class_exists( 'Productive_Theme_Customiser_Layout' ) ) {
    
    /**
     * Productive_Theme_Customiser_Layout
     * Theme Customiser Class
     */
    class Productive_Theme_Customiser_Layout extends Productive_Theme_Customiser_Common {
        
        /**
         * Register the customizer
         *
         * @param WP_Customize_Manager $wp_customise param.
         */
        public static function register( $wp_customise ) {
            
            // See common for Panels
            // 
            // Section
            $wp_customise->add_section(
                'productive_ecommerce_layout_options',
                array(
                    'title' => __( 'Layout Options', 'productive-ecommerce' ),
                    'description' => __( 'Layout Options', 'productive-ecommerce' ),
                    'panel' => 'productive_ecommerce_theme_options',
                    'priority' => 50,
                    'capability' => 'edit_theme_options',
                )
                );
            
            // add a setting for productive_ecommerce_show_page_titles control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_show_page_titles',
                array(
                    'type' => 'theme_mod',
                    'default' => true,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_checkbox'),
                )
                );
            
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_show_page_titles',
                array(
                    'type' => 'checkbox',
                    'priority' => 30,
                    'section' => 'productive_ecommerce_layout_options',
                    'label' => __( 'Display Page Titles?', 'productive-ecommerce' ),
                    'description' => __( 'Display page titles on Pages or not (this does not affect blog Posts, it is only applicable to pages)', 'productive-ecommerce' ),
                )
                );
            
            // add a setting for productive_ecommerce_page_banner_image control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_page_banner_image',
                array(
                    'type' => 'theme_mod',
                    'default' => true,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_image'),
                )
                );
            
            // add control.
            $wp_customise->add_control(
                new WP_Customize_Media_Control(
                    $wp_customise,
                    'productive_ecommerce_page_banner_image',
                    array(
                        'priority' => 32,
                        'section' => 'productive_ecommerce_layout_options',
                        'label' => __( 'Page Banner Image', 'productive-ecommerce' ),
                        'description' => __( 'Top banner image for Pages', 'productive-ecommerce' ),
                        // 'active_callback' => 'is_front_page'
                    )
                    )
                );
            
            // add a setting for productive_ecommerce_404_banner_image control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_404_banner_image',
                array(
                    'type' => 'theme_mod',
                    'default' => true,
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_image'),
                )
                );
            
            // add control.
            $wp_customise->add_control(
                new WP_Customize_Media_Control(
                    $wp_customise,
                    'productive_ecommerce_404_banner_image',
                    array(
                        'priority' => 34,
                        'section' => 'productive_ecommerce_layout_options',
                        'label' => __( '404 Banner Image', 'productive-ecommerce' ),
                        'description' => __( 'Top banner image for 404 (error page)', 'productive-ecommerce' ),
                        // 'active_callback' => 'is_front_page'
                    )
                    )
                );
            
            // add a setting for productive_ecommerce_template_layout_options control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_template_layout_options',
                array(
                    'type' => 'theme_mod',
                    'default' => 'one_column',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_select'),
                )
                );
            
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_template_layout_options',
                array(
                    'type' => 'radio',
                    'priority' => 60,
                    'section' => 'productive_ecommerce_layout_options',
                    'label' => __( 'Layout options for templates', 'productive-ecommerce' ),
                    'description' => '',
                    'choices' => array(
                        'one_column' => __( 'One Column', 'productive-ecommerce' ),
                        'two_columns_left' => __( 'Two Column Left Sidebar', 'productive-ecommerce' ),
                        'two_columns_right' => __( 'Two Column Right Sidebar', 'productive-ecommerce' ),
                        'three_columns' => __( 'Three columns', 'productive-ecommerce' ),
                    ),
                )
                );
            
            // add a setting for productive_ecommerce_sidebar_left_header_text control, below.
            $wp_customise->add_setting(
                'productive_ecommerce_sidebar_left_header_text',
                array(
                    'type' => 'theme_mod',
                    'default' => 'Info',
                    'theme_supports' => '',
                    'transport' => 'refresh',
                    'capability' => 'edit_theme_options',
                    'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_no_html'),
                )
                );
            
            // add control..
            $wp_customise->add_control(
                'productive_ecommerce_sidebar_left_header_text',
                array(
                    'type' => 'text',
                    'priority' => 70,
                    'section' => 'productive_ecommerce_layout_options',
                    'label' => 'Small Screen Left Sidebar Header',
                    'description' => 'Text to display on small screens left sidebar header',
                    // 'active_callback' => 'is_front_page'
                )
                );
            
        }
        
    } // End of class.
    
    // add hook for the class.
    add_action( 'customize_register', array( 'Productive_Theme_Customiser_Layout', 'register' ) );
    
}// End of if class exists


/**
 * Method productive_ecommerce_show_page_titles.
 *
 * @param string $class ''.
 */
function productive_ecommerce_show_page_titles() {
    return get_theme_mod( 'productive_ecommerce_show_page_titles', true );
}

/**
 * Method productive_ecommerce_page_banner_image.
 *
 * @param string $class ''.
 */
function productive_ecommerce_page_banner_image() {
    return get_theme_mod( 'productive_ecommerce_page_banner_image' );
}

/**
 * Method productive_ecommerce_404_banner_image.
 *
 * @param string $class ''.
 */
function productive_ecommerce_404_banner_image() {
    return get_theme_mod( 'productive_ecommerce_404_banner_image' );
}


/**
 * Method productive_ecommerce_template_layout_options.
 *
 * @param string $class ''.
 */
function productive_ecommerce_template_layout_options( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_template_layout_options', 'one_column' );
}
add_action( 'display_productive_ecommerce_template_layout_options', 'productive_ecommerce_template_layout_options' );

/**
 * Method productive_ecommerce_sidebar_left_header_text.
 *
 * @param string $class ''.
 */
function productive_ecommerce_sidebar_left_header_text( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_sidebar_left_header_text', esc_html__( 'Info', 'productive-ecommerce' ) );
}
add_action( 'display_productive_ecommerce_sidebar_left_header_text', 'productive_ecommerce_sidebar_left_header_text' );

/**
 * Method display_productive_ecommerce_layout_fullwidth.
 *
 * @param string $class ''.
 */
function productive_ecommerce_layout_fullwidth( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_layout_fullwidth', false );
}
add_action( 'display_productive_ecommerce_layout_fullwidth', 'productive_ecommerce_layout_fullwidth' );

/**
 * Method productive_ecommerce_layout_content_width.
 *
 * @param string $class ''.
 */
function productive_ecommerce_layout_content_width( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_layout_content_width', '' );
}

