<?php
/**
 * Theme Customiser
 *
 * @package productive-ecommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
    die();
}


if ( ! class_exists( 'Productive_Theme_Customiser_Newsletter' ) ) {
    
    /**
     * Productive_Theme_Customiser_Newsletter
     * Theme Customiser Class
     */
    class Productive_Theme_Customiser_Newsletter extends Productive_Theme_Customiser_Common {
        
        /**
         * Register the customizer
         *
         * @param WP_Customize_Manager $wp_customise param.
         */
        public static function register( $wp_customise ) {
            
            // See common for Panels
            // 
            if ( productive_ecommerce_is_productive_forms_active() ) {
                
                // Section
                $wp_customise->add_section(
                    'productive_ecommerce_newsletter_options',
                    array(
                        'title' => __( 'Newsletter Options', 'productive-ecommerce' ),
                        'description' => __( 'Switch newsletter on/off. Please go to the Plugin settings for detailed configurations of the newsletter.', 'productive-ecommerce' ),
                        'panel' => 'productive_ecommerce_theme_options',
                        'priority' => 22,
                        'capability' => 'edit_theme_options',
                    )
                    );
            
                $wp_customise->add_setting(
                    'productive_ecommerce_newsletter_switch_on',
                    array(
                        'type' => 'theme_mod',
                        'default' => true,
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_checkbox'),
                    )
                    );
                // add control..
                $wp_customise->add_control(
                    'productive_ecommerce_newsletter_switch_on',
                    array(
                        'type' => 'checkbox',
                        'priority' => 10,
                        'section' => 'productive_ecommerce_newsletter_options',
                        'label' => __( 'Show Newsletter?', 'productive-ecommerce' ),
                        'description' => __( 'Show newsletter opt-in form on website', 'productive-ecommerce' ),
                    )
                    );

                // add a setting for productive_ecommerce_newsletter_banner_bg_pattern control, below.
                $wp_customise->add_setting(
                    'productive_ecommerce_newsletter_layout',
                    array(
                        'type' => 'theme_mod',
                        'default' => 'select_an_option',
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_select'),
                    )
                    );

                // add control..
                $wp_customise->add_control(
                    'productive_ecommerce_newsletter_layout',
                    array(
                        'type' => 'select',
                        'priority' => 20,
                        'section' => 'productive_ecommerce_newsletter_options',
                        'label' => __( 'Newsletter Layout', 'productive-ecommerce' ),
                        'description' => '',
                        'choices' => array(
                            'select_an_option' => __( 'Select an option', 'productive-ecommerce' ),
                            'portrait' => __( 'Portrait', 'productive-ecommerce' ),
                            'landscape' => __( 'Landscape', 'productive-ecommerce' )
                        ),
                    )
                    );

                if (productive_ecommerce_is_productive_forms_extra_active() ) {
                    // add a setting for productive_ecommerce_newsletter_banner_bg_pattern control, below.
                    $wp_customise->add_setting(
                        'productive_ecommerce_newsletter_form_submission_type',
                        array(
                            'type' => 'theme_mod',
                            'default' => 'select_an_option',
                            'theme_supports' => '',
                            'transport' => 'refresh',
                            'capability' => 'edit_theme_options',
                            'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_select'),
                        )
                        );

                    // add control..
                    $wp_customise->add_control(
                        'productive_ecommerce_newsletter_form_submission_type',
                        array(
                            'type' => 'select',
                            'priority' => 30,
                            'section' => 'productive_ecommerce_newsletter_options',
                            'label' => __( 'Form Submission', 'productive-ecommerce' ),
                            'description' => '',
                            'choices' => array(
                                'select_an_option' => __( 'Select an option', 'productive-ecommerce' ),
                                'ajax' => __( 'Ajax Form', 'productive-ecommerce' ),
                                'standard' => __( 'Standard Form', 'productive-ecommerce' )
                            ),
                        )
                        );
                }
            } else {
                
            // Section
            $wp_customise->add_section(
                'productive_ecommerce_newsletter_options',
                array(
                    'title' => __( 'Newsletter Options', 'productive-ecommerce' ),
                    'description' => __( 'Productive Forms Plugin is not detected! Please go to, Appearance => Theme Plugins, to install theme plugins and try again.', 'productive-ecommerce' ),
                    'panel' => 'productive_ecommerce_theme_options',
                    'priority' => 22,
                    'capability' => 'edit_theme_options',
                )
                );
            
                $wp_customise->add_setting(
                    'productive_ecommerce_newsletter_switch_on',
                    array(
                        'type' => 'theme_mod',
                        'default' => '',
                        'theme_supports' => '',
                        'transport' => 'refresh',
                        'capability' => 'edit_theme_options',
                        'sanitize_callback' => array(__CLASS__, 'productive_ecommerce_sanitize_checkbox'),
                    )
                    );
                // add control..
                $wp_customise->add_control(
                    'productive_ecommerce_newsletter_switch_on',
                    array(
                        'type' => 'hidden',
                        'priority' => 10,
                        'section' => 'productive_ecommerce_newsletter_options',
                        'label' => '',
                        'description' => '',
                    )
                    );

            }
            // END: NEWSLETTER
            
            
        }
        
    } // End of class.
    
    // add hook for the class.
    add_action( 'customize_register', array( 'Productive_Theme_Customiser_Newsletter', 'register' ) );
    
} // End of if class exists


/**
 * Method productive_ecommerce_newsletter_switch_on.
 *
 * @param string $class ''.
 */
function productive_ecommerce_newsletter_switch_on( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_newsletter_switch_on', true );
}

/**
 * Method productive_ecommerce_newsletter_layout.
 *
 * @param string $class ''.
 */
function productive_ecommerce_newsletter_layout( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_newsletter_layout', 'landscape' );
}

/**
 * Method productive_ecommerce_newsletter_form_submission_type.
 *
 * @param string $class ''.
 */
function productive_ecommerce_newsletter_form_submission_type( $class = '' ) {
    return get_theme_mod( 'productive_ecommerce_newsletter_form_submission_type', 'select_an_option' );
}

