<?php
/**
 *
 * @package productive-ecommerce
 */

if ( !defined('ABSPATH') ) {
	die();
}

require PRODUCTIVE_ECOMMERCE_THEME_BASE_PATH . '/options/partials/section-one.php';
require PRODUCTIVE_ECOMMERCE_THEME_BASE_PATH . '/standard/options/partials/section-go-pro.php';
require PRODUCTIVE_ECOMMERCE_THEME_BASE_PATH . '/includes/productiveminds-theme-dashboad-items.php';

$productive_ecommerce_admin_navbar_title = PRODUCTIVE_ECOMMERCE_CURRENT_THEME_NAME . esc_html__( ' Admin Settings and Options', 'productive-ecommerce' );

/**
 * Render Pages and Menus
 * 
 * @global string $productive_ecommerce_admin_navbar_title
 */
function productive_ecommerce_plugin_options_render_page_menu() {
    
    global $productive_ecommerce_admin_navbar_title;
        
    $menu_title         = PRODUCTIVE_ECOMMERCE_OPTION_MENU_TITLE;
    $capability         = 'administrator';
    $position           = 100; 
    
    add_theme_page( 
        $productive_ecommerce_admin_navbar_title, 
        $menu_title, 
        $capability, 
        PRODUCTIVE_ECOMMERCE_ADMIN_PAGE_REQUEST_URI, 
        'productive_ecommerce_plugin_options_render_page_menu_html', 
        $position
    );    
}
add_action( 'admin_menu', 'productive_ecommerce_plugin_options_render_page_menu' );

function productive_ecommerce_plugin_options_render_page_menu_html() {
    // check user capabilities
    if ( !current_user_can( 'manage_options' ) ) {
        add_settings_error( 'productive_ecommerce_admin_messages', 'productive_ecommerce_admin_message', esc_html__( 'You do not have permission to access this page.', 'productive-ecommerce' ), 'error' );
        settings_errors( 'productive_ecommerce_admin_messages' );
    } else {
            
    // check if the user have submitted the settings
    $is_error_count_section_1 = count( get_settings_errors('productiveminds_section_1_options') );
    if ( isset( $_GET['settings-updated'] ) && $is_error_count_section_1 < 1 ) {
        // add settings saved message with the class of "updated"
        add_settings_error( 'productive_ecommerce_admin_messages', 'productive_ecommerce_admin_message', __( 'Settings Saved', 'productive-ecommerce' ), 'updated' );
    }
    settings_errors( 'productive_ecommerce_admin_messages' );
    
    ?>
    <?php 
        $active_tab = 'section_1_options_tab';
            if( isset( $_GET[ 'tab' ] ) ) {
                $active_tab = sanitize_text_field( $_GET[ 'tab' ] );
            }		
    ?>

    <div class="wrap productive-ecommerce-options-page-wrapper">
        <div class="page-wrapper-heading">
            <h1>
                <img style="vertical-align: middle; margin-right: 10px; border-radius: 5px;" src="<?php echo PRODUCTIVE_ECOMMERCE_THEME_BASE_URI . '/screenshot.png' ?>" alt="" width="60px" height="45px" />
                <?php echo PRODUCTIVE_ECOMMERCE_CURRENT_THEME_NAME; ?>
                <a target="_blank" class="page-wrapper-heading-get-pro" href="<?php echo PRODUCTIVE_ECOMMERCE_THEME_DOCUMENTATION_URL; ?>"><?php _e( 'Documentation', 'productive-ecommerce' ); ?></a>
                <a target="_blank" class="page-wrapper-heading-get-pro" href="<?php echo PRODUCTIVE_ECOMMERCE_THEME_DOCUMENTATION_URL; ?>/support"><?php _e( 'Get Support', 'productive-ecommerce' ); ?></a>
            </h1>
        </div>
        <div class="page-wrapper-body">
                
            <div class="page-wrapper-options-error">
                <?php settings_errors('productiveminds_section_1_options'); ?>
                <?php settings_errors('productiveminds_section_pro_options'); ?>
            </div>

            <?php
                $section_1_options_tab_active = '';
                if ( $active_tab === 'section_1_options_tab' ) {
                    $section_1_options_tab_active = 'nav-tab-active';
                }
                $section_pro_options_tab = '';
                if ( $active_tab === 'section_pro_options_tab' ) {
                    $section_pro_options_tab = 'nav-tab-active';
                }
            ?>
            <h2 class="nav-tab-wrapper">
                <a href="?page=<?php echo PRODUCTIVE_ECOMMERCE_ADMIN_PAGE_REQUEST_URI; ?>&tab=section_1_options_tab" class="nav-tab <?php echo esc_attr( $section_1_options_tab_active ); ?>"><?php echo PRODUCTIVE_ECOMMERCE_OPTION_TAB_1_TITLE; ?></a>
                <a href="?page=<?php echo PRODUCTIVE_ECOMMERCE_ADMIN_PAGE_REQUEST_URI; ?>&tab=section_pro_options_tab" class="nav-tab <?php echo esc_attr( $section_pro_options_tab ); ?>"><?php echo PRODUCTIVE_ECOMMERCE_OPTION_TAB_PRO_TITLE; ?></a>
            </h2>
            
            <div class="page-wrapper-body-form">
                
                <?php if ( $active_tab === 'section_1_options_tab' ) { ?>
                    <div class="flex-content-container">
                        <div class="flex-content-70">
                            <?php
                                productive_ecommerce_theme_dashboard_section_content();
                                productive_ecommerce_theme_dashboard_section_customizers();
                                productive_ecommerce_theme_dashboard_section_plugin_forms();
                                productive_ecommerce_theme_dashboard_section_plugin_commerce();
                            ?>
                        </div>
                        <div class="flex-content-30">
                            <?php
                                productive_ecommerce_theme_dashboard_section_about();
                            ?>
                        </div>
                    </div>
                <?php } else if ( $active_tab === 'section_pro_options_tab' ) { ?>
                    <?php
                        productiveminds_section_get_pro();
                   ?>
                <?php } ?>
            </div>
            
            <div class="leave-a-review-box">
                <?php _e( 'We would like to seek your support as we continue to improve and update ', 'productive-ecommerce' ); ?>
                <?php echo PRODUCTIVE_ECOMMERCE_CURRENT_THEME_NAME; ?>.
                <?php _e( 'To support us, ', 'productive-ecommerce' ); ?>
                <a target="_blank" href="<?php echo PRODUCTIVE_ECOMMERCE_THEME_REVIEW_ON_REPO_URL; ?>">
                    <?php _e( 'please leave a review here', 'productive-ecommerce' ); ?>
               </a>
            </div>

        </div>
    </div>

    <?php
    }
}
